summaryrefslogtreecommitdiff
path: root/src/pkg/syscall/passfd_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/pkg/syscall/passfd_test.go')
-rw-r--r--src/pkg/syscall/passfd_test.go7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/pkg/syscall/passfd_test.go b/src/pkg/syscall/passfd_test.go
index e16debae1..53c7a1ffa 100644
--- a/src/pkg/syscall/passfd_test.go
+++ b/src/pkg/syscall/passfd_test.go
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
// +build linux darwin freebsd netbsd openbsd
package syscall_test
@@ -13,6 +13,7 @@ import (
"net"
"os"
"os/exec"
+ "runtime"
"syscall"
"testing"
"time"
@@ -26,6 +27,10 @@ import (
// "-test.run=^TestPassFD$" and an environment variable used to signal
// that the test should become the child process instead.
func TestPassFD(t *testing.T) {
+ if runtime.GOOS == "dragonfly" {
+ // TODO(jsing): Figure out why sendmsg is returning EINVAL.
+ t.Skip("Skipping test on dragonfly")
+ }
if os.Getenv("GO_WANT_HELPER_PROCESS") == "1" {
passFDChild()
return
@@ -2,7 +2,7 @@
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.
-// +build linux darwin freebsd netbsd openbsd
+// +build linux dragonfly darwin freebsd netbsd openbsd
package syscall_test